"""
SQLShell - A powerful SQL shell with GUI interface for data analysis
"""

__version__ = "0.2.3"
__author__ = "SQLShell Team"

from sqlshell.main import main

def start():
    """Start the SQLShell application."""
    main()

# SQLShell package initialization 